/****************************************************************************
** Meta object code from reading C++ file 'decorationsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdecoration-6.6.4/src/decorationsettings.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto KDecoration3::DecorationSettings::qt_create_metaobjectdata<qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDecoration3::DecorationSettings",
        "onAllDesktopsAvailableChanged",
        "",
        "alphaChannelSupportedChanged",
        "closeOnDoubleClickOnMenuChanged",
        "alwaysShowExcludeFromCaptureChanged",
        "decorationButtonsLeftChanged",
        "QList<KDecoration3::DecorationButtonType>",
        "decorationButtonsRightChanged",
        "borderSizeChanged",
        "KDecoration3::BorderSize",
        "size",
        "fontChanged",
        "QFont",
        "font",
        "gridUnitChanged",
        "spacingChanged",
        "reconfigured",
        "onAllDesktopsAvailable",
        "alphaChannelSupported",
        "closeOnDoubleClickOnMenu",
        "alwaysShowExcludeFromCapture",
        "decorationButtonsLeft",
        "decorationButtonsRight",
        "borderSize",
        "gridUnit",
        "smallSpacing",
        "largeSpacing"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onAllDesktopsAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'alphaChannelSupportedChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'closeOnDoubleClickOnMenuChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'alwaysShowExcludeFromCaptureChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'decorationButtonsLeftChanged'
        QtMocHelpers::SignalData<void(const QList<KDecoration3::DecorationButtonType> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'decorationButtonsRightChanged'
        QtMocHelpers::SignalData<void(const QList<KDecoration3::DecorationButtonType> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'borderSizeChanged'
        QtMocHelpers::SignalData<void(KDecoration3::BorderSize)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'gridUnitChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'spacingChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reconfigured'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'onAllDesktopsAvailable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'alphaChannelSupported'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'closeOnDoubleClickOnMenu'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'alwaysShowExcludeFromCapture'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'decorationButtonsLeft'
        QtMocHelpers::PropertyData<QList<KDecoration3::DecorationButtonType>>(22, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'decorationButtonsRight'
        QtMocHelpers::PropertyData<QList<KDecoration3::DecorationButtonType>>(23, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'borderSize'
        QtMocHelpers::PropertyData<KDecoration3::BorderSize>(24, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'gridUnit'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'smallSpacing'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'largeSpacing'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecorationSettings, qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDecoration3::DecorationSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>.metaTypes,
    nullptr
} };

void KDecoration3::DecorationSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecorationSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAllDesktopsAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->alphaChannelSupportedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->closeOnDoubleClickOnMenuChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->alwaysShowExcludeFromCaptureChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->decorationButtonsLeftChanged((*reinterpret_cast<std::add_pointer_t<QList<KDecoration3::DecorationButtonType>>>(_a[1]))); break;
        case 5: _t->decorationButtonsRightChanged((*reinterpret_cast<std::add_pointer_t<QList<KDecoration3::DecorationButtonType>>>(_a[1]))); break;
        case 6: _t->borderSizeChanged((*reinterpret_cast<std::add_pointer_t<KDecoration3::BorderSize>>(_a[1]))); break;
        case 7: _t->fontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 8: _t->gridUnitChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->spacingChanged(); break;
        case 10: _t->reconfigured(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KDecoration3::DecorationButtonType> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KDecoration3::DecorationButtonType> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDecoration3::BorderSize >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(bool )>(_a, &DecorationSettings::onAllDesktopsAvailableChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(bool )>(_a, &DecorationSettings::alphaChannelSupportedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(bool )>(_a, &DecorationSettings::closeOnDoubleClickOnMenuChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(bool )>(_a, &DecorationSettings::alwaysShowExcludeFromCaptureChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(const QList<KDecoration3::DecorationButtonType> & )>(_a, &DecorationSettings::decorationButtonsLeftChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(const QList<KDecoration3::DecorationButtonType> & )>(_a, &DecorationSettings::decorationButtonsRightChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(KDecoration3::BorderSize )>(_a, &DecorationSettings::borderSizeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(const QFont & )>(_a, &DecorationSettings::fontChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)(int )>(_a, &DecorationSettings::gridUnitChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)()>(_a, &DecorationSettings::spacingChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationSettings::*)()>(_a, &DecorationSettings::reconfigured, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration3::BorderSize >(); break;
        case 5:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KDecoration3::DecorationButtonType> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isOnAllDesktopsAvailable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isAlphaChannelSupported(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isCloseOnDoubleClickOnMenu(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isAlwaysShowExcludeFromCapture(); break;
        case 4: *reinterpret_cast<QList<KDecoration3::DecorationButtonType>*>(_v) = _t->decorationButtonsLeft(); break;
        case 5: *reinterpret_cast<QList<KDecoration3::DecorationButtonType>*>(_v) = _t->decorationButtonsRight(); break;
        case 6: *reinterpret_cast<KDecoration3::BorderSize*>(_v) = _t->borderSize(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->gridUnit(); break;
        case 8: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->smallSpacing(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->largeSpacing(); break;
        default: break;
        }
    }
}

const QMetaObject *KDecoration3::DecorationSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration3::DecorationSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration318DecorationSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration3::DecorationSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KDecoration3::DecorationSettings::onAllDesktopsAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDecoration3::DecorationSettings::alphaChannelSupportedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDecoration3::DecorationSettings::closeOnDoubleClickOnMenuChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDecoration3::DecorationSettings::alwaysShowExcludeFromCaptureChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDecoration3::DecorationSettings::decorationButtonsLeftChanged(const QList<KDecoration3::DecorationButtonType> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDecoration3::DecorationSettings::decorationButtonsRightChanged(const QList<KDecoration3::DecorationButtonType> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDecoration3::DecorationSettings::borderSizeChanged(KDecoration3::BorderSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDecoration3::DecorationSettings::fontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDecoration3::DecorationSettings::gridUnitChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDecoration3::DecorationSettings::spacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KDecoration3::DecorationSettings::reconfigured()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
