/****************************************************************************
** Meta object code from reading C++ file 'decorationbutton.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdecoration-6.6.4/src/decorationbutton.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDecoration316DecorationButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto KDecoration3::DecorationButton::qt_create_metaobjectdata<qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDecoration3::DecorationButton",
        "clicked",
        "",
        "Qt::MouseButton",
        "pressed",
        "released",
        "pointerEntered",
        "pointerLeft",
        "doubleClicked",
        "pressedChanged",
        "hoveredChanged",
        "enabledChanged",
        "checkableChanged",
        "checkedChanged",
        "geometryChanged",
        "QRectF",
        "acceptedButtonsChanged",
        "Qt::MouseButtons",
        "visibilityChanged",
        "setEnabled",
        "enabled",
        "setCheckable",
        "checkable",
        "setChecked",
        "checked",
        "setVisible",
        "visible",
        "update",
        "rect",
        "hovered",
        "geometry",
        "acceptedButtons"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(Qt::MouseButton)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'released'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerEntered'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerLeft'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'hoveredChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'checkableChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'checkedChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Signal 'acceptedButtonsChanged'
        QtMocHelpers::SignalData<void(Qt::MouseButtons)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'visibilityChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setCheckable'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setChecked'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setVisible'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void(const QRectF &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 28 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'hovered'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'checkable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'checked'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'geometry'
        QtMocHelpers::PropertyData<QRectF>(30, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'acceptedButtons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(31, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecorationButton, qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDecoration3::DecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>.metaTypes,
    nullptr
} };

void KDecoration3::DecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecorationButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<Qt::MouseButton>>(_a[1]))); break;
        case 1: _t->pressed(); break;
        case 2: _t->released(); break;
        case 3: _t->pointerEntered(); break;
        case 4: _t->pointerLeft(); break;
        case 5: _t->doubleClicked(); break;
        case 6: _t->pressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->hoveredChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->checkableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->checkedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->geometryChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 12: _t->acceptedButtonsChanged((*reinterpret_cast<std::add_pointer_t<Qt::MouseButtons>>(_a[1]))); break;
        case 13: _t->visibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setCheckable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->update((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 19: _t->update(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(Qt::MouseButton )>(_a, &DecorationButton::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)()>(_a, &DecorationButton::pressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)()>(_a, &DecorationButton::released, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)()>(_a, &DecorationButton::pointerEntered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)()>(_a, &DecorationButton::pointerLeft, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)()>(_a, &DecorationButton::doubleClicked, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::pressedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::hoveredChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::enabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::checkableChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::checkedChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(const QRectF & )>(_a, &DecorationButton::geometryChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(Qt::MouseButtons )>(_a, &DecorationButton::acceptedButtonsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationButton::*)(bool )>(_a, &DecorationButton::visibilityChanged, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPressed(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isHovered(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isCheckable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isChecked(); break;
        case 6: *reinterpret_cast<QRectF*>(_v) = _t->geometry(); break;
        case 7: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->acceptedButtons(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setCheckable(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setChecked(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setAcceptedButtons(*reinterpret_cast<Qt::MouseButtons*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KDecoration3::DecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration3::DecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationButtonE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration3::DecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KDecoration3::DecorationButton::clicked(Qt::MouseButton _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDecoration3::DecorationButton::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration3::DecorationButton::released()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDecoration3::DecorationButton::pointerEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDecoration3::DecorationButton::pointerLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDecoration3::DecorationButton::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KDecoration3::DecorationButton::pressedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDecoration3::DecorationButton::hoveredChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDecoration3::DecorationButton::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDecoration3::DecorationButton::checkableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KDecoration3::DecorationButton::checkedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KDecoration3::DecorationButton::geometryChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KDecoration3::DecorationButton::acceptedButtonsChanged(Qt::MouseButtons _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KDecoration3::DecorationButton::visibilityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
