/****************************************************************************
** Meta object code from reading C++ file 'decoration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdecoration-6.6.4/src/decoration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDecoration310DecorationE_t {};
} // unnamed namespace

template <> constexpr inline auto KDecoration3::Decoration::qt_create_metaobjectdata<qt_meta_tag_ZN12KDecoration310DecorationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDecoration3::Decoration",
        "blurRegionChanged",
        "",
        "bordersChanged",
        "resizeOnlyBordersChanged",
        "sectionUnderMouseChanged",
        "Qt::WindowFrameSection",
        "titleBarChanged",
        "opaqueChanged",
        "shadowChanged",
        "std::shared_ptr<DecorationShadow>",
        "shadow",
        "damaged",
        "QRegion",
        "region",
        "currentStateChanged",
        "std::shared_ptr<DecorationState>",
        "state",
        "nextStateChanged",
        "borderRadiusChanged",
        "borderOutlineChanged",
        "requestClose",
        "requestToggleMaximization",
        "Qt::MouseButtons",
        "buttons",
        "requestMinimize",
        "requestContextHelp",
        "requestToggleOnAllDesktops",
        "requestToggleShade",
        "requestToggleKeepAbove",
        "requestToggleKeepBelow",
        "requestToggleExcludeFromCapture",
        "requestShowWindowMenu",
        "QRect",
        "rect",
        "requestShowToolTip",
        "text",
        "requestHideToolTip",
        "showApplicationMenu",
        "actionId",
        "requestShowApplicationMenu",
        "update",
        "QRectF",
        "init",
        "borders",
        "QMarginsF",
        "borderLeft",
        "borderRight",
        "borderTop",
        "borderBottom",
        "resizeOnlyBorders",
        "resizeOnlyBorderLeft",
        "resizeOnlyBorderRight",
        "resizeOnlyBorderTop",
        "resizeOnlyBorderBottom",
        "sectionUnderMouse",
        "titleBar",
        "opaque"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'blurRegionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bordersChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resizeOnlyBordersChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sectionUnderMouseChanged'
        QtMocHelpers::SignalData<void(Qt::WindowFrameSection)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'titleBarChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opaqueChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'shadowChanged'
        QtMocHelpers::SignalData<void(const std::shared_ptr<DecorationShadow> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'damaged'
        QtMocHelpers::SignalData<void(const QRegion &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'currentStateChanged'
        QtMocHelpers::SignalData<void(std::shared_ptr<DecorationState>)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'nextStateChanged'
        QtMocHelpers::SignalData<void(std::shared_ptr<DecorationState>)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'borderRadiusChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderOutlineChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestClose'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleMaximization'
        QtMocHelpers::SlotData<void(Qt::MouseButtons)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'requestMinimize'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestContextHelp'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleOnAllDesktops'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleShade'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleKeepAbove'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleKeepBelow'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestToggleExcludeFromCapture'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestShowWindowMenu'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestShowWindowMenu'
        QtMocHelpers::SlotData<void(const QRect &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'requestShowToolTip'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'requestHideToolTip'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showApplicationMenu'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'requestShowApplicationMenu'
        QtMocHelpers::SlotData<void(const QRect &, int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void(const QRectF &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 34 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<bool()>(43, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'borders'
        QtMocHelpers::PropertyData<QMarginsF>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'borderLeft'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'borderRight'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'borderTop'
        QtMocHelpers::PropertyData<qreal>(48, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'borderBottom'
        QtMocHelpers::PropertyData<qreal>(49, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'resizeOnlyBorders'
        QtMocHelpers::PropertyData<QMarginsF>(50, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'resizeOnlyBorderLeft'
        QtMocHelpers::PropertyData<qreal>(51, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'resizeOnlyBorderRight'
        QtMocHelpers::PropertyData<qreal>(52, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'resizeOnlyBorderTop'
        QtMocHelpers::PropertyData<qreal>(53, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'resizeOnlyBorderBottom'
        QtMocHelpers::PropertyData<qreal>(54, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'sectionUnderMouse'
        QtMocHelpers::PropertyData<Qt::WindowFrameSection>(55, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'titleBar'
        QtMocHelpers::PropertyData<QRectF>(56, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'opaque'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Decoration, qt_meta_tag_ZN12KDecoration310DecorationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDecoration3::Decoration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration310DecorationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration310DecorationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDecoration310DecorationE_t>.metaTypes,
    nullptr
} };

void KDecoration3::Decoration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Decoration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->blurRegionChanged(); break;
        case 1: _t->bordersChanged(); break;
        case 2: _t->resizeOnlyBordersChanged(); break;
        case 3: _t->sectionUnderMouseChanged((*reinterpret_cast<std::add_pointer_t<Qt::WindowFrameSection>>(_a[1]))); break;
        case 4: _t->titleBarChanged(); break;
        case 5: _t->opaqueChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->shadowChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<DecorationShadow>>>(_a[1]))); break;
        case 7: _t->damaged((*reinterpret_cast<std::add_pointer_t<QRegion>>(_a[1]))); break;
        case 8: _t->currentStateChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<DecorationState>>>(_a[1]))); break;
        case 9: _t->nextStateChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<DecorationState>>>(_a[1]))); break;
        case 10: _t->borderRadiusChanged(); break;
        case 11: _t->borderOutlineChanged(); break;
        case 12: _t->requestClose(); break;
        case 13: _t->requestToggleMaximization((*reinterpret_cast<std::add_pointer_t<Qt::MouseButtons>>(_a[1]))); break;
        case 14: _t->requestMinimize(); break;
        case 15: _t->requestContextHelp(); break;
        case 16: _t->requestToggleOnAllDesktops(); break;
        case 17: _t->requestToggleShade(); break;
        case 18: _t->requestToggleKeepAbove(); break;
        case 19: _t->requestToggleKeepBelow(); break;
        case 20: _t->requestToggleExcludeFromCapture(); break;
        case 21: _t->requestShowWindowMenu(); break;
        case 22: _t->requestShowWindowMenu((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 23: _t->requestShowToolTip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->requestHideToolTip(); break;
        case 25: _t->showApplicationMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->requestShowApplicationMenu((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->update((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 28: _t->update(); break;
        case 29: { bool _r = _t->init();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::blurRegionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::bordersChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::resizeOnlyBordersChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(Qt::WindowFrameSection )>(_a, &Decoration::sectionUnderMouseChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::titleBarChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(bool )>(_a, &Decoration::opaqueChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(const std::shared_ptr<DecorationShadow> & )>(_a, &Decoration::shadowChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(const QRegion & )>(_a, &Decoration::damaged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(std::shared_ptr<DecorationState> )>(_a, &Decoration::currentStateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)(std::shared_ptr<DecorationState> )>(_a, &Decoration::nextStateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::borderRadiusChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Decoration::*)()>(_a, &Decoration::borderOutlineChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QMarginsF*>(_v) = _t->borders(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->borderLeft(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->borderRight(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->borderTop(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->borderBottom(); break;
        case 5: *reinterpret_cast<QMarginsF*>(_v) = _t->resizeOnlyBorders(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->resizeOnlyBorderLeft(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->resizeOnlyBorderRight(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->resizeOnlyBorderTop(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->resizeOnlyBorderBottom(); break;
        case 10: *reinterpret_cast<Qt::WindowFrameSection*>(_v) = _t->sectionUnderMouse(); break;
        case 11: *reinterpret_cast<QRectF*>(_v) = _t->titleBar(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isOpaque(); break;
        default: break;
        }
    }
}

const QMetaObject *KDecoration3::Decoration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration3::Decoration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration310DecorationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration3::Decoration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KDecoration3::Decoration::blurRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDecoration3::Decoration::bordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration3::Decoration::resizeOnlyBordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDecoration3::Decoration::sectionUnderMouseChanged(Qt::WindowFrameSection _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDecoration3::Decoration::titleBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDecoration3::Decoration::opaqueChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDecoration3::Decoration::shadowChanged(const std::shared_ptr<DecorationShadow> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDecoration3::Decoration::damaged(const QRegion & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDecoration3::Decoration::currentStateChanged(std::shared_ptr<DecorationState> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDecoration3::Decoration::nextStateChanged(std::shared_ptr<DecorationState> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KDecoration3::Decoration::borderRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KDecoration3::Decoration::borderOutlineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
