/****************************************************************************
** Meta object code from reading C++ file 'decorationshadow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdecoration-6.6.4/src/decorationshadow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationshadow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDecoration316DecorationShadowE_t {};
} // unnamed namespace

template <> constexpr inline auto KDecoration3::DecorationShadow::qt_create_metaobjectdata<qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDecoration3::DecorationShadow",
        "shadowChanged",
        "",
        "QImage",
        "innerShadowRectChanged",
        "paddingChanged",
        "shadow",
        "innerShadowRect",
        "QRectF",
        "topLeftGeometry",
        "topGeometry",
        "topRightGeometry",
        "rightGeometry",
        "bottomRightGeometry",
        "bottomGeometry",
        "bottomLeftGeometry",
        "leftGeometry",
        "paddingTop",
        "paddingRight",
        "paddingBottom",
        "paddingLeft",
        "padding",
        "QMarginsF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shadowChanged'
        QtMocHelpers::SignalData<void(const QImage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'innerShadowRectChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paddingChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shadow'
        QtMocHelpers::PropertyData<QImage>(6, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'innerShadowRect'
        QtMocHelpers::PropertyData<QRectF>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'topLeftGeometry'
        QtMocHelpers::PropertyData<QRectF>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'topGeometry'
        QtMocHelpers::PropertyData<QRectF>(10, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'topRightGeometry'
        QtMocHelpers::PropertyData<QRectF>(11, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'rightGeometry'
        QtMocHelpers::PropertyData<QRectF>(12, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'bottomRightGeometry'
        QtMocHelpers::PropertyData<QRectF>(13, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'bottomGeometry'
        QtMocHelpers::PropertyData<QRectF>(14, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'bottomLeftGeometry'
        QtMocHelpers::PropertyData<QRectF>(15, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'leftGeometry'
        QtMocHelpers::PropertyData<QRectF>(16, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'paddingTop'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'paddingRight'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'paddingBottom'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'paddingLeft'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'padding'
        QtMocHelpers::PropertyData<QMarginsF>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecorationShadow, qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDecoration3::DecorationShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>.metaTypes,
    nullptr
} };

void KDecoration3::DecorationShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecorationShadow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shadowChanged((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->innerShadowRectChanged(); break;
        case 2: _t->paddingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecorationShadow::*)(const QImage & )>(_a, &DecorationShadow::shadowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationShadow::*)()>(_a, &DecorationShadow::innerShadowRectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecorationShadow::*)()>(_a, &DecorationShadow::paddingChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QImage*>(_v) = _t->shadow(); break;
        case 1: *reinterpret_cast<QRectF*>(_v) = _t->innerShadowRect(); break;
        case 2: *reinterpret_cast<QRectF*>(_v) = _t->topLeftGeometry(); break;
        case 3: *reinterpret_cast<QRectF*>(_v) = _t->topGeometry(); break;
        case 4: *reinterpret_cast<QRectF*>(_v) = _t->topRightGeometry(); break;
        case 5: *reinterpret_cast<QRectF*>(_v) = _t->rightGeometry(); break;
        case 6: *reinterpret_cast<QRectF*>(_v) = _t->bottomRightGeometry(); break;
        case 7: *reinterpret_cast<QRectF*>(_v) = _t->bottomGeometry(); break;
        case 8: *reinterpret_cast<QRectF*>(_v) = _t->bottomLeftGeometry(); break;
        case 9: *reinterpret_cast<QRectF*>(_v) = _t->leftGeometry(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->paddingTop(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->paddingRight(); break;
        case 12: *reinterpret_cast<qreal*>(_v) = _t->paddingBottom(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->paddingLeft(); break;
        case 14: *reinterpret_cast<QMarginsF*>(_v) = _t->padding(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShadow(*reinterpret_cast<QImage*>(_v)); break;
        case 1: _t->setInnerShadowRect(*reinterpret_cast<QRectF*>(_v)); break;
        case 14: _t->setPadding(*reinterpret_cast<QMarginsF*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KDecoration3::DecorationShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration3::DecorationShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration316DecorationShadowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration3::DecorationShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KDecoration3::DecorationShadow::shadowChanged(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDecoration3::DecorationShadow::innerShadowRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration3::DecorationShadow::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
