/****************************************************************************
** Meta object code from reading C++ file 'decoratedwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdecoration-6.6.4/src/decoratedwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoratedwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KDecoration3::DecoratedWindow::qt_create_metaobjectdata<qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDecoration3::DecoratedWindow",
        "activeChanged",
        "",
        "captionChanged",
        "onAllDesktopsChanged",
        "shadedChanged",
        "iconChanged",
        "QIcon",
        "maximizedChanged",
        "maximizedHorizontallyChanged",
        "maximizedVerticallyChanged",
        "keepAboveChanged",
        "keepBelowChanged",
        "excludeFromCaptureChanged",
        "closeableChanged",
        "maximizeableChanged",
        "minimizeableChanged",
        "providesContextHelpChanged",
        "shadeableChanged",
        "moveableChanged",
        "resizeableChanged",
        "widthChanged",
        "heightChanged",
        "sizeChanged",
        "QSizeF",
        "size",
        "paletteChanged",
        "QPalette",
        "palette",
        "adjacentScreenEdgesChanged",
        "Qt::Edges",
        "edges",
        "hasApplicationMenuChanged",
        "applicationMenuActiveChanged",
        "scaleChanged",
        "nextScaleChanged",
        "applicationMenuChanged",
        "decoration",
        "KDecoration3::Decoration*",
        "active",
        "caption",
        "onAllDesktops",
        "shaded",
        "icon",
        "maximized",
        "maximizedHorizontally",
        "maximizedVertically",
        "keepAbove",
        "keepBelow",
        "excludeFromCapture",
        "closeable",
        "maximizeable",
        "minimizeable",
        "providesContextHelp",
        "modal",
        "shadeable",
        "moveable",
        "resizeable",
        "width",
        "height",
        "adjacentScreenEdges",
        "hasApplicationMenu",
        "applicationMenuActive",
        "applicationMenuServiceName",
        "applicationMenuObjectPath",
        "scale",
        "nextScale"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'captionChanged'
        QtMocHelpers::SignalData<void(QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'onAllDesktopsChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'shadedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(QIcon)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'maximizedChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'maximizedHorizontallyChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'maximizedVerticallyChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'keepAboveChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'keepBelowChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'excludeFromCaptureChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'closeableChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'maximizeableChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'minimizeableChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'providesContextHelpChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'shadeableChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'moveableChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'resizeableChanged'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void(qreal)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void(qreal)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(const QSizeF &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void(const QPalette &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'adjacentScreenEdgesChanged'
        QtMocHelpers::SignalData<void(Qt::Edges)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Signal 'hasApplicationMenuChanged'
        QtMocHelpers::SignalData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'applicationMenuActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextScaleChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationMenuChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'decoration'
        QtMocHelpers::PropertyData<KDecoration3::Decoration*>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'caption'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'onAllDesktops'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'shaded'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'icon'
        QtMocHelpers::PropertyData<QIcon>(43, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'maximized'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'maximizedHorizontally'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'maximizedVertically'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'keepAbove'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'keepBelow'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'excludeFromCapture'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'closeable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'maximizeable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'minimizeable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'providesContextHelp'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'modal'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shadeable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'moveable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags, 16),
        // property 'resizeable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(58, QMetaType::QReal, QMC::DefaultPropertyFlags, 18),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(59, QMetaType::QReal, QMC::DefaultPropertyFlags, 19),
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 20),
        // property 'palette'
        QtMocHelpers::PropertyData<QPalette>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 21),
        // property 'adjacentScreenEdges'
        QtMocHelpers::PropertyData<Qt::Edges>(60, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 22),
        // property 'hasApplicationMenu'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
        // property 'applicationMenuActive'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 24),
        // property 'applicationMenuServiceName'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'applicationMenuObjectPath'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'scale'
        QtMocHelpers::PropertyData<qreal>(65, QMetaType::QReal, QMC::DefaultPropertyFlags, 25),
        // property 'nextScale'
        QtMocHelpers::PropertyData<qreal>(66, QMetaType::QReal, QMC::DefaultPropertyFlags, 26),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DecoratedWindow, qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDecoration3::DecoratedWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>.metaTypes,
    nullptr
} };

void KDecoration3::DecoratedWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DecoratedWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->captionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onAllDesktopsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->shadedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[1]))); break;
        case 5: _t->maximizedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->maximizedHorizontallyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->maximizedVerticallyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->keepAboveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->keepBelowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->excludeFromCaptureChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->closeableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->maximizeableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->minimizeableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->providesContextHelpChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->shadeableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->moveableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->resizeableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->widthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 19: _t->heightChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 20: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 21: _t->paletteChanged((*reinterpret_cast<std::add_pointer_t<QPalette>>(_a[1]))); break;
        case 22: _t->adjacentScreenEdgesChanged((*reinterpret_cast<std::add_pointer_t<Qt::Edges>>(_a[1]))); break;
        case 23: _t->hasApplicationMenuChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->applicationMenuActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->scaleChanged(); break;
        case 26: _t->nextScaleChanged(); break;
        case 27: _t->applicationMenuChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(QString )>(_a, &DecoratedWindow::captionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::onAllDesktopsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::shadedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(QIcon )>(_a, &DecoratedWindow::iconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::maximizedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::maximizedHorizontallyChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::maximizedVerticallyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::keepAboveChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::keepBelowChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::excludeFromCaptureChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::closeableChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::maximizeableChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::minimizeableChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::providesContextHelpChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::shadeableChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::moveableChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::resizeableChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(qreal )>(_a, &DecoratedWindow::widthChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(qreal )>(_a, &DecoratedWindow::heightChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(const QSizeF & )>(_a, &DecoratedWindow::sizeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(const QPalette & )>(_a, &DecoratedWindow::paletteChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(Qt::Edges )>(_a, &DecoratedWindow::adjacentScreenEdgesChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::hasApplicationMenuChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)(bool )>(_a, &DecoratedWindow::applicationMenuActiveChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)()>(_a, &DecoratedWindow::scaleChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)()>(_a, &DecoratedWindow::nextScaleChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DecoratedWindow::*)()>(_a, &DecoratedWindow::applicationMenuChanged, 27))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration3::Decoration* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KDecoration3::Decoration**>(_v) = _t->decoration(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->caption(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isOnAllDesktops(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isShaded(); break;
        case 5: *reinterpret_cast<QIcon*>(_v) = _t->icon(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isMaximized(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isMaximizedHorizontally(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isMaximizedVertically(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isKeepAbove(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isKeepBelow(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isExcludedFromCapture(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isCloseable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isMaximizeable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isMinimizeable(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->providesContextHelp(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isModal(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isShadeable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isMoveable(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isResizeable(); break;
        case 20: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 21: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 22: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        case 23: *reinterpret_cast<QPalette*>(_v) = _t->palette(); break;
        case 24: *reinterpret_cast<Qt::Edges*>(_v) = _t->adjacentScreenEdges(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->hasApplicationMenu(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isApplicationMenuActive(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->applicationMenuServiceName(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->applicationMenuObjectPath(); break;
        case 29: *reinterpret_cast<qreal*>(_v) = _t->scale(); break;
        case 30: *reinterpret_cast<qreal*>(_v) = _t->nextScale(); break;
        default: break;
        }
    }
}

const QMetaObject *KDecoration3::DecoratedWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration3::DecoratedWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDecoration315DecoratedWindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration3::DecoratedWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void KDecoration3::DecoratedWindow::activeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDecoration3::DecoratedWindow::captionChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDecoration3::DecoratedWindow::onAllDesktopsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDecoration3::DecoratedWindow::shadedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDecoration3::DecoratedWindow::iconChanged(QIcon _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDecoration3::DecoratedWindow::maximizedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDecoration3::DecoratedWindow::maximizedHorizontallyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDecoration3::DecoratedWindow::maximizedVerticallyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDecoration3::DecoratedWindow::keepAboveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDecoration3::DecoratedWindow::keepBelowChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KDecoration3::DecoratedWindow::excludeFromCaptureChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KDecoration3::DecoratedWindow::closeableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KDecoration3::DecoratedWindow::maximizeableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KDecoration3::DecoratedWindow::minimizeableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void KDecoration3::DecoratedWindow::providesContextHelpChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void KDecoration3::DecoratedWindow::shadeableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void KDecoration3::DecoratedWindow::moveableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void KDecoration3::DecoratedWindow::resizeableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void KDecoration3::DecoratedWindow::widthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void KDecoration3::DecoratedWindow::heightChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void KDecoration3::DecoratedWindow::sizeChanged(const QSizeF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void KDecoration3::DecoratedWindow::paletteChanged(const QPalette & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void KDecoration3::DecoratedWindow::adjacentScreenEdgesChanged(Qt::Edges _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void KDecoration3::DecoratedWindow::hasApplicationMenuChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void KDecoration3::DecoratedWindow::applicationMenuActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void KDecoration3::DecoratedWindow::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void KDecoration3::DecoratedWindow::nextScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void KDecoration3::DecoratedWindow::applicationMenuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
